@@ -17,7 +17,7 @@ sub _carp {
     return warn @_, " at $file line $line\n";
 }
 
-our $VERSION = '1.302209';
+our $VERSION = '1.302211';
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
@@ -177,7 +177,7 @@ sub import_extra {
     my $class = shift;
     my $list  = shift;
 
-    my @other = ();
+    my @other;
     my $idx   = 0;
     my $import;
     while( $idx <= $#{$list} ) {
@@ -579,7 +579,7 @@ sub can_ok ($@) {
         return $ok;
     }
 
-    my @nok = ();
+    my @nok;
     foreach my $method (@methods) {
         $tb->_try( sub { $proto->can($method) } ) or push @nok, $method;
     }
@@ -997,7 +997,7 @@ import anything, use C<require_ok>.
 
 sub use_ok ($;@) {
     my( $module, @imports ) = @_;
-    @imports = () unless @imports;
+
     my $tb = Test::More->builder;
 
     my %caller;
@@ -1185,7 +1185,7 @@ sub _format_stack {
     }
 
     my @vals = @{ $Stack[-1]{vals} }[ 0, 1 ];
-    my @vars = ();
+    my @vars;
     ( $vars[0] = $var ) =~ s/\$FOO/     \$got/;
     ( $vars[1] = $var ) =~ s/\$FOO/\$expected/;
 
@@ -2004,7 +2004,7 @@ L<Test::Most> Most commonly needed test functions and features.
 
 =head1 ENVIRONMENT VARIABLES
 
-See L<Test2::Env> for a list of meaningul environment variables.
+See L<Test2::Env> for a list of meaningful environment variables.
 
 =head1 AUTHORS
 
