@@ -1,6 +1,6 @@
 package Test2::Manual::Tooling::TestBuilder;
 
-our $VERSION = '1.302209';
+our $VERSION = '1.302211';
 
 1;
 
@@ -102,7 +102,7 @@ use the C<Test2::API::run_subtest()> function instead. See L<Test2::API> for doc
 
 =item $tb->todo_end
 
-See L<Test2::Tools::Todo> instead.
+See L<Test2::Tools::Basic/"skip($why)">, and L<Test2::Todo> instead.
 
 =item $tb->output, $tb->failure_output, and $tb->todo_output
 
